###
TRF
###

*******
Summary
*******

.. automodule:: pymedphys.trf
    :no-members:



***
API
***

Work with Elekta Linac Agility Head TRFs
----------------------------------------

.. autofunction:: pymedphys.trf.read

.. autofunction:: pymedphys.trf.identify
